==> zio-aws-kafka_3-5.17.104.10-sources.jar: zio/aws/kafka/model/NodeExporterInfo.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__boolean
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class NodeExporterInfo(enabledInBroker: __boolean) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.NodeExporterInfo = {
    import NodeExporterInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.NodeExporterInfo
      .builder()
      .enabledInBroker(__boolean.unwrap(enabledInBroker): java.lang.Boolean)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.NodeExporterInfo.ReadOnly =
    zio.aws.kafka.model.NodeExporterInfo.wrap(buildAwsValue())
}
object NodeExporterInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.NodeExporterInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.NodeExporterInfo =
      zio.aws.kafka.model.NodeExporterInfo(enabledInBroker)
    def enabledInBroker: __boolean
    def getEnabledInBroker: ZIO[Any, Nothing, __boolean] =
      ZIO.succeed(enabledInBroker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.NodeExporterInfo
  ) extends zio.aws.kafka.model.NodeExporterInfo.ReadOnly {
    override val enabledInBroker: __boolean =
      zio.aws.kafka.model.primitives.__boolean(impl.enabledInBroker())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.NodeExporterInfo
  ): zio.aws.kafka.model.NodeExporterInfo.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_3-7.21.15.3-sources.jar: zio/aws/kafka/model/NodeExporterInfo.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__boolean
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class NodeExporterInfo(enabledInBroker: __boolean) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.NodeExporterInfo = {
    import NodeExporterInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.NodeExporterInfo
      .builder()
      .enabledInBroker(enabledInBroker: java.lang.Boolean)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.NodeExporterInfo.ReadOnly =
    zio.aws.kafka.model.NodeExporterInfo.wrap(buildAwsValue())
}
object NodeExporterInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.NodeExporterInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.NodeExporterInfo =
      zio.aws.kafka.model.NodeExporterInfo(enabledInBroker)
    def enabledInBroker: __boolean
    def getEnabledInBroker: ZIO[Any, Nothing, __boolean] =
      ZIO.succeed(enabledInBroker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.NodeExporterInfo
  ) extends zio.aws.kafka.model.NodeExporterInfo.ReadOnly {
    override val enabledInBroker: __boolean = impl.enabledInBroker(): __boolean
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.NodeExporterInfo
  ): zio.aws.kafka.model.NodeExporterInfo.ReadOnly = new Wrapper(impl)
}
